<?php
// api/request-permission.php - Send permission request to organization owner
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../helpers/AuthHelper.php';
require_once __DIR__ . '/../helpers/RoleHelper.php';

AuthHelper::requireLogin();

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'error' => 'POST method required']);
    exit;
}

$permission = $_POST['permission'] ?? null;
$userId = $_SESSION['user_id'];
$organizationId = $_SESSION['organization_id'];

if (!$permission) {
    echo json_encode(['success' => false, 'error' => 'Permission parameter required']);
    exit;
}

try {
    // Get user info
    $stmt = $pdo->prepare("SELECT first_name, last_name, email FROM whsale_inventory_pro_users WHERE id = ?");
    $stmt->execute([$userId]);
    $user = $stmt->fetch();
    
    // Get organization owner
    $stmt = $pdo->prepare("SELECT first_name, last_name, email FROM whsale_inventory_pro_users WHERE organization_id = ? AND role = 'owner' LIMIT 1");
    $stmt->execute([$organizationId]);
    $owner = $stmt->fetch();
    
    if (!$owner) {
        echo json_encode(['success' => false, 'error' => 'Organization owner not found']);
        exit;
    }
    
    // Get permission details
    $allPermissions = RoleHelper::getAllPermissions();
    $permissionDetails = $allPermissions[$permission] ?? ['name' => $permission, 'description' => 'Access to ' . $permission];
    
    // Create permission request record
    $stmt = $pdo->prepare("
        INSERT INTO whsale_inventory_pro_permission_requests (
            user_id, organization_id, permission_key, permission_name, 
            requested_at, status
        ) VALUES (?, ?, ?, ?, NOW(), 'pending')
        ON DUPLICATE KEY UPDATE 
            requested_at = NOW(),
            status = 'pending'
    ");
    $stmt->execute([$userId, $organizationId, $permission, $permissionDetails['name']]);
    
    // Send email notification to owner (optional - implement if you have email system)
    // $emailSent = sendPermissionRequestEmail($owner, $user, $permissionDetails);
    
    echo json_encode([
        'success' => true,
        'message' => 'Permission request sent successfully',
        'permission' => $permission
    ]);
    
} catch (Exception $e) {
    error_log("Permission request error: " . $e->getMessage());
    echo json_encode([
        'success' => false,
        'error' => 'Failed to send permission request'
    ]);
}
?>