<?php
// helpers/PermissionMiddleware.php - Middleware for protecting routes
class PermissionMiddleware {
    
    /**
     * Check permission and redirect if not authorized
     */
    public static function requirePermission($permission, $redirectUrl = null) {
        if (!RoleHelper::hasPermission($permission)) {
            $redirectUrl = $redirectUrl ?: BASE_URL . "dashboard";
            $_SESSION['error'] = "You don't have permission to access this feature.";
            $_SESSION['missing_permission'] = $permission;
            header("Location: " . $redirectUrl);
            exit;
        }
    }
    
    /**
     * Check permission for AJAX requests
     */
    public static function requirePermissionAjax($permission) {
        if (!RoleHelper::hasPermission($permission)) {
            http_response_code(403);
            echo json_encode([
                'success' => false,
                'error' => 'Permission denied',
                'missing_permission' => $permission,
                'required_permission_name' => self::getPermissionName($permission)
            ]);
            exit;
        }
    }
    
    /**
     * Get human-readable permission name
     */
    private static function getPermissionName($permission) {
        $allPermissions = RoleHelper::getAllPermissions();
        return $allPermissions[$permission]['name'] ?? $permission;
    }
    
    /**
     * Check multiple permissions (user needs at least one)
     */
    public static function requireAnyPermission($permissions, $redirectUrl = null) {
        $hasAny = false;
        foreach ($permissions as $permission) {
            if (RoleHelper::hasPermission($permission)) {
                $hasAny = true;
                break;
            }
        }
        
        if (!$hasAny) {
            $redirectUrl = $redirectUrl ?: BASE_URL . "dashboard";
            $_SESSION['error'] = "You don't have permission to access this feature.";
            $_SESSION['missing_permissions'] = $permissions;
            header("Location: " . $redirectUrl);
            exit;
        }
    }
    
    /**
     * Check all permissions (user needs all of them)
     */
    public static function requireAllPermissions($permissions, $redirectUrl = null) {
        foreach ($permissions as $permission) {
            if (!RoleHelper::hasPermission($permission)) {
                $redirectUrl = $redirectUrl ?: BASE_URL . "dashboard";
                $_SESSION['error'] = "You don't have sufficient permissions to access this feature.";
                $_SESSION['missing_permission'] = $permission;
                header("Location: " . $redirectUrl);
                exit;
            }
        }
    }
}