<?php
// routes.php

require_once __DIR__ . '/controllers/StorefrontController.php'; // 👈 Ensure controller is included

// ✅ Root route to handle home screen behavior
$router->get('/', function () {
    if (!isset($_SESSION['user_id'])) {
        header("Location: /IbeamInventoryPro2/login");
    } else {
        header("Location: /IbeamInventoryPro2/dashboard");
    }
    exit;
});


// GET ROUTES

// Authentication and Dashboard
$router->get('/dashboard', 'views/dashboard.php');
$router->get('/login', 'views/login.php');
$router->get('/logout', 'logout.php');
$router->get('/register', 'views/register.php');

// Employee Invitation System
$router->get('/auth/complete-invitation', 'auth/complete-invitation.php');

// Admin Routes (User Management & Invitations)
$router->get('/admin/invite-employee', 'admin/invite-employee.php');
$router->get('/admin/manage-users', 'admin/manage-users.php');
$router->get('/admin/organization-settings', 'admin/organization-settings.php');

// Pallet Receiving
$router->get('/receiving/add', 'views/receiving/add.php');
$router->get('/receiving', 'views/receiving/index.php');
$router->get('/receiving/confirmation', 'views/receiving/confirmation.php');
$router->get('/receiving/view', 'views/receiving/view.php');
$router->get('/receiving/edit', 'views/receiving/edit.php');
$router->get('/receiving/upload_photo', 'views/receiving/upload_photo.php');

// Pallet Inventory Items
$router->get('/inventory/add', 'views/inventory/add.php');
$router->get('/inventory/edit', 'views/inventory/edit.php');
$router->get('/inventory', 'views/inventory/manage.php');
$router->get('/inventory/view', 'views/inventory/view.php');
// $router->get('/inventory/delete', 'views/inventory/delete.php');

// Storefront Posting
$router->get('/storefront/upload_form', 'views/storefront/upload_form.php');
$router->get('/storefront/confirmation', function () {
    $receiving_id = $_GET['receiving_id'] ?? null;
    if (!$receiving_id || !is_numeric($receiving_id)) {
        header("Location: /IbeamInventoryPro2/dashboard");
        exit;
    }
    StorefrontController::showConfirmation($receiving_id);
});

// Storefront Product Management (Authenticated)
$router->get('/storefront/manage', 'views/storefront/manage.php');
$router->get('/storefront/manage/edit', 'views/storefront/edit.php');

// Storefront Public Facing Views (Dynamic)
$router->get('/storefront/(:any)/(:num)', [StorefrontController::class, 'showProduct']);     // /storefront/BobsDeals/123
$router->get('/storefront/(:any)', [StorefrontController::class, 'showIndex']);
         // /storefront/BobsDeals

// Legacy direct access (for admin or fallback)
$router->get('/storefront/home', 'views/storefront/index.php');             // /storefront?org=1
$router->get('/storefront/view', 'views/storefront/view.php');         // /storefront/view?id=23

// Storefront Profile Views
$router->get('/storefront/profile/view', 'views/storefront/profile/view.php');
$router->get('/storefront/profile/edit', 'views/storefront/profile/edit.php');


// POST ROUTES

// Authentication
$router->post('/login', 'views/login.php');
$router->post('/register', 'views/register.php');

// Employee Invitation System
$router->post('/auth/complete-invitation', 'auth/complete-invitation.php');

// Admin Routes (User Management & Invitations)
$router->post('/admin/invite-employee', 'admin/invite-employee.php');
$router->post('/admin/manage-users', 'admin/manage-users.php');
$router->post('/admin/resend-invitation', 'admin/resend-invitation.php');
$router->post('/admin/cancel-invitation', 'admin/cancel-invitation.php');
$router->post('/admin/organization-settings', 'admin/organization-settings.php');

// Pallet Receiving
$router->post('/receiving/add', 'views/receiving/add.php');
$router->post('/receiving/edit', 'views/receiving/edit.php');
$router->post('/receiving/upload_photo', 'views/receiving/upload_photo.php');
$router->post('/receiving/delete_photo', 'views/receiving/delete_photo.php');
$router->post('/receiving/update_photo_caption', 'views/receiving/update_photo_caption.php');

// Pallet Inventory Items
$router->post('/inventory/add', 'views/inventory/add.php');
$router->post('/inventory/edit', 'views/inventory/edit.php');
$router->post('/inventory/delete', 'views/inventory/delete.php');
$router->post('/inventory/delete_photo', 'views/inventory/delete_photo.php');
$router->post('/inventory/update_photo_caption', 'views/inventory/update_photo_caption.php');

// Storefront Posting
$router->post('/storefront/publish', 'views/storefront/publish.php');

// Storefront Product Management (Authenticated)
$router->post('/storefront/manage/edit', 'views/storefront/edit.php');
$router->post('/storefront/manage/delete', 'views/storefront/manage_delete.php');

$router->post('/storefront/manage/edit', 'views/storefront/manage_edit.php');

// Storefront Customer Contact Email Form
$router->post('/storefront/contact', 'views/storefront/contact_handler.php');

// Storefront Profile Views
$router->post('/storefront/profile/edit', 'views/storefront/profile/edit.php');

// Permission Management Routes (Owner only)
$router->get('/admin/manage-admin-permissions', 'admin/manage-admin-permissions.php');
$router->post('/admin/manage-admin-permissions', 'admin/manage-admin-permissions.php');

// Permission API Routes  
$router->get('/api/check-permission', 'api/check-permission.php');
$router->post('/api/request-permission', 'api/request-permission.php');
$router->get('/api/get-user-permissions', 'api/get-user-permissions.php');