<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Check permission but allow owners to bypass
AuthHelper::requireLogin();

header('Content-Type: application/json');

// Check if user has permission (owners automatically have all permissions)
if (!RoleHelper::isOwner() && !RoleHelper::hasPermission('edit_inventory')) {
    http_response_code(403);
    echo json_encode([
        'success' => false,
        'error' => 'Permission denied',
        'missing_permission' => 'edit_inventory'
    ]);
    exit;
}

$photo_id = $_POST['photo_id'] ?? null;
$caption = trim($_POST['caption'] ?? '');
$user_id = AuthHelper::getUserId();
$organization_id = $_SESSION['organization_id'];

if (!$photo_id || !is_numeric($photo_id)) {
    http_response_code(400);
    echo json_encode(['success' => false, 'error' => 'Invalid photo ID.']);
    exit;
}

try {
    // UPDATED: Enhanced security - verify photo belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT ip.id, ip.caption 
        FROM whsale_inventory_pro_inventory_photos ip
        JOIN whsale_inventory_pro_inventory_items ii ON ip.item_id = ii.id
        WHERE ip.id = ? AND ii.organization_id = ?
    ");
    $stmt->execute([$photo_id, $organization_id]);
    $photoData = $stmt->fetch();
    
    if (!$photoData) {
        echo json_encode(['success' => false, 'error' => 'Photo not found or access denied.']);
        exit;
    }
    
    // Update caption
    $stmt = $pdo->prepare("UPDATE whsale_inventory_pro_inventory_photos SET caption = ? WHERE id = ?");
    $stmt->execute([$caption, $photo_id]);

    echo json_encode([
        'success' => true, 
        'message' => 'Caption updated successfully',
        'caption' => $caption
    ]);
} catch (Exception $e) {
    error_log("Error updating inventory photo caption: " . $e->getMessage());
    http_response_code(500);
    echo json_encode(['success' => false, 'error' => 'Failed to update caption.']);
}