<?php if (session_status() === PHP_SESSION_NONE) session_start(); ?>

<nav class="navbar navbar-expand-lg navbar-dark bg-dark mb-4 shadow-sm">
  <div class="container-fluid">

    <!-- Logo / Home Link -->
    <a class="navbar-brand" href="<?= BASE_URL ?>dashboard">
        <img src="<?= BASE_URL ?>assets/logo_white.png" alt="Inventory Logo" height="30">
    </a>

    <!-- Toggle for mobile -->
    <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarMain" aria-controls="navbarMain" aria-expanded="false" aria-label="Toggle navigation">
      <span class="navbar-toggler-icon"></span>
    </button>

    <!-- Collapsible content -->
    <div class="collapse navbar-collapse" id="navbarMain">
      <ul class="navbar-nav me-auto mb-2 mb-lg-0">
        <!-- Future nav links can go here -->
        <!--
        <li class="nav-item">
          <a class="nav-link" href="<?= BASE_URL ?>receiving">Receiving</a>
        </li>
        -->

        <!-- Admin Menu - Show only to users with employee management permissions -->
        <?php 
        // Check if user has any employee management permissions
        $canManageEmployees = false;
        $userPermissions = $_SESSION['user_permissions'] ?? [];
        
        if (isset($_SESSION['user_role'])) {
          if ($_SESSION['user_role'] === 'owner') {
            $canManageEmployees = true; // Owners always have access
          } elseif ($_SESSION['user_role'] === 'admin') {
            // Check if admin has employee management permissions from session
            $canManageEmployees = in_array('invite_employees', $userPermissions) || 
                                 in_array('manage_employee_accounts', $userPermissions) || 
                                 in_array('manage_admin_permissions', $userPermissions);
          }
        }
        
        // Helper function to check permissions from session
        function hasSessionPermission($permission) {
          $userRole = $_SESSION['user_role'] ?? 'user';
          if ($userRole === 'owner') return true;
          $userPermissions = $_SESSION['user_permissions'] ?? [];
          return in_array($permission, $userPermissions);
        }
        ?>
        
        <?php if ($canManageEmployees): ?>
          <li class="nav-item dropdown">
            <a class="nav-link dropdown-toggle" href="#" id="adminDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
              <i class="fas fa-users-cog me-1"></i>Manage Organization
            </a>
            <ul class="dropdown-menu" aria-labelledby="adminDropdown">
              <!-- Show menu items based on specific permissions -->
              <?php if (hasSessionPermission('invite_employees')): ?>
                <li>
                  <a class="dropdown-item" href="<?= BASE_URL ?>admin/invite-employee">
                    <i class="fas fa-user-plus me-2"></i>Invite Employee
                  </a>
                </li>
              <?php endif; ?>
              
              <?php if (hasSessionPermission('manage_employee_accounts')): ?>
                <li>
                  <a class="dropdown-item" href="<?= BASE_URL ?>admin/manage-users">
                    <i class="fas fa-users me-2"></i>Manage Users
                  </a>
                </li>
              <?php endif; ?>
              
              <!-- Admin Permissions Management (Owner Only) -->
              <?php if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'owner'): ?>
                <li>
                  <a class="dropdown-item" href="<?= BASE_URL ?>admin/manage-admin-permissions">
                    <i class="fas fa-user-shield me-2"></i>Manage Admin Permissions
                  </a>
                </li>
              <?php endif; ?>
              
              <!-- Show divider only if there are items above and below -->
              <?php /* if ((hasSessionPermission('invite_employees') || hasSessionPermission('manage_employee_accounts') || ($_SESSION['user_role'] === 'owner')) && hasSessionPermission('manage_organization_settings')): ?>
                <li><hr class="dropdown-divider"></li>
              <?php endif; ?>
              
              <?php
              <?php if (hasSessionPermission('manage_organization_settings')): ?>
                <li>
                  <a class="dropdown-item" href="<?= BASE_URL ?>admin/organization-settings">
                    <i class="fas fa-cog me-2"></i>Organization Settings
                    
                  </a>
                </li>
              <?php endif; */?>
             
            </ul>
          </li>
        <?php endif; ?>
      </ul>
      

      <!-- Logged-in user & logout -->
      <div class="d-flex flex-column flex-lg-row align-items-lg-center gap-2">
        <span class="navbar-text text-white small">
          <?= htmlspecialchars($_SESSION['username'] ?? '') ?>
          <?php if (isset($_SESSION['user_role'])): ?>
            <?php if ($_SESSION['user_role'] === 'owner'): ?>
              <span class="badge bg-warning text-dark ms-1">
                <i class="fas fa-crown me-1"></i>Owner
              </span>
            <?php elseif ($_SESSION['user_role'] === 'admin'): ?>
              <?php
              // UPDATED: Get admin's permission template name
              $adminTemplate = null;
              if (isset($_SESSION['user_id'])) {
                try {
                  $stmt = $pdo->prepare("
                    SELECT template_name 
                    FROM whsale_inventory_pro_user_permissions 
                    WHERE user_id = ? AND template_name IS NOT NULL 
                    ORDER BY granted_at DESC 
                    LIMIT 1
                  ");
                  $stmt->execute([$_SESSION['user_id']]);
                  $result = $stmt->fetch();
                  if ($result) {
                    $adminTemplate = $result['template_name'];
                  }
                  $stmt->closeCursor();
                } catch (Exception $e) {
                  error_log("Error fetching admin template: " . $e->getMessage());
                }
              }
              ?>
              
              <?php if ($adminTemplate): ?>
                <span class="badge bg-info ms-1">
                  <i class="fas fa-user-tag me-1"></i><?= htmlspecialchars($adminTemplate) ?>
                </span>
              <?php else: ?>
                <span class="badge bg-success ms-1">
                  <i class="fas fa-user-shield me-1"></i>Employee
                </span>
              <?php endif; ?>
            <?php endif; ?>
          <?php endif; ?>
        </span>
        <a class="btn btn-outline-light btn-sm" href="<?= BASE_URL ?>logout">Logout</a>
      </div>
    </div>
  </div>
</nav>