<?php
// views/partials/permission_modal.php - Permission warning modal component
// Include this in your head.php or footer.php
?>

<!-- Permission Denied Modal -->
<div class="modal fade" id="permissionDeniedModal" tabindex="-1" data-bs-backdrop="static" data-bs-keyboard="false">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content border-0 shadow">
            <div class="modal-header bg-warning text-dark border-0">
                <div class="d-flex align-items-center">
                    <i class="fas fa-shield-alt fa-2x me-3"></i>
                    <div>
                        <h5 class="modal-title mb-0">Permission Required</h5>
                        <small>Access Restricted</small>
                    </div>
                </div>
            </div>
            <div class="modal-body p-4">
                <div class="text-center mb-3">
                    <i class="fas fa-lock fa-3x text-muted mb-3"></i>
                    <h6 class="text-dark">You don't have permission to perform this action</h6>
                </div>
                
                <div class="alert alert-light border" id="permissionDetails">
                    <strong>Required Permission:</strong>
                    <span id="missingPermissionName" class="text-primary"></span>
                    <br>
                    <small class="text-muted" id="missingPermissionDescription"></small>
                </div>
                
                <div class="text-center">
                    <p class="text-muted mb-3">Contact your organization owner to request this permission.</p>
                    <div class="d-flex gap-2 justify-content-center">
                        <button type="button" class="btn btn-outline-primary btn-sm" onclick="requestPermission()">
                            <i class="fas fa-envelope me-1"></i>Request Access
                        </button>
                        <button type="button" class="btn btn-secondary btn-sm" data-bs-dismiss="modal">
                            <i class="fas fa-times me-1"></i>Close
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Permission Request Success Modal -->
<div class="modal fade" id="permissionRequestModal" tabindex="-1">
    <div class="modal-dialog modal-dialog-centered modal-sm">
        <div class="modal-content border-0 shadow">
            <div class="modal-body text-center p-4">
                <i class="fas fa-paper-plane fa-3x text-success mb-3"></i>
                <h6>Request Sent!</h6>
                <p class="text-muted small mb-3">Your permission request has been sent to the organization owner.</p>
                <button type="button" class="btn btn-success btn-sm" data-bs-dismiss="modal">
                    <i class="fas fa-check me-1"></i>Got it
                </button>
            </div>
        </div>
    </div>
</div>

<script>
// Permission checking system
const permissionSystem = {
    // All available permissions with descriptions
    permissions: <?= json_encode(RoleHelper::getAllPermissions()) ?>,
    
    // Check if user has permission before allowing action
    checkPermission: function(permission, callback) {
        fetch(`<?= BASE_URL ?>api/check-permission?permission=${permission}`)
            .then(response => response.json())
            .then(data => {
                if (data.hasPermission) {
                    callback();
                } else {
                    this.showPermissionModal(permission);
                }
            })
            .catch(error => {
                console.error('Permission check failed:', error);
                this.showPermissionModal(permission);
            });
    },
    
    // Show permission denied modal
    showPermissionModal: function(permission) {
        const permissionData = this.permissions[permission];
        
        if (permissionData) {
            document.getElementById('missingPermissionName').textContent = permissionData.name;
            document.getElementById('missingPermissionDescription').textContent = permissionData.description;
        } else {
            document.getElementById('missingPermissionName').textContent = permission;
            document.getElementById('missingPermissionDescription').textContent = 'This action requires special permissions.';
        }
        
        new bootstrap.Modal(document.getElementById('permissionDeniedModal')).show();
    },
    
    // Intercept form submissions that require permissions
    protectForm: function(formSelector, requiredPermission) {
        document.addEventListener('DOMContentLoaded', function() {
            const form = document.querySelector(formSelector);
            if (form) {
                form.addEventListener('submit', function(e) {
                    e.preventDefault();
                    permissionSystem.checkPermission(requiredPermission, function() {
                        form.submit();
                    });
                });
            }
        });
    },
    
    // Protect buttons/links that require permissions
    protectButton: function(buttonSelector, requiredPermission) {
        document.addEventListener('DOMContentLoaded', function() {
            const buttons = document.querySelectorAll(buttonSelector);
            buttons.forEach(button => {
                button.addEventListener('click', function(e) {
                    e.preventDefault();
                    const originalAction = button.getAttribute('href') || button.getAttribute('data-action');
                    
                    permissionSystem.checkPermission(requiredPermission, function() {
                        if (originalAction) {
                            if (button.tagName === 'A') {
                                window.location.href = originalAction;
                            } else if (button.getAttribute('data-action')) {
                                eval(originalAction); // For JavaScript actions
                            }
                        }
                    });
                });
            });
        });
    }
};

// Request permission from owner
function requestPermission() {
    const permission = document.getElementById('missingPermissionName').textContent;
    
    fetch('<?= BASE_URL ?>api/request-permission', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        body: `permission=${encodeURIComponent(permission)}`
    })
    .then(response => response.json())
    .then(data => {
        document.getElementById('permissionDeniedModal').querySelector('.btn-close').click();
        
        setTimeout(() => {
            new bootstrap.Modal(document.getElementById('permissionRequestModal')).show();
        }, 300);
    })
    .catch(error => {
        console.error('Permission request failed:', error);
    });
}

// Auto-check permissions on page load for elements with data-permission attribute
document.addEventListener('DOMContentLoaded', function() {
    const protectedElements = document.querySelectorAll('[data-permission]');
    
    protectedElements.forEach(element => {
        const requiredPermission = element.getAttribute('data-permission');
        
        // Check permission and hide/disable element if not allowed
        fetch(`<?= BASE_URL ?>api/check-permission?permission=${requiredPermission}`)
            .then(response => response.json())
            .then(data => {
                if (!data.hasPermission) {
                    if (element.tagName === 'BUTTON' || element.tagName === 'INPUT') {
                        element.disabled = true;
                        element.title = 'You do not have permission for this action';
                    } else {
                        element.style.opacity = '0.5';
                        element.style.pointerEvents = 'none';
                        element.title = 'You do not have permission for this action';
                    }
                    
                    // Add click handler to show modal
                    element.addEventListener('click', function(e) {
                        e.preventDefault();
                        e.stopPropagation();
                        permissionSystem.showPermissionModal(requiredPermission);
                    });
                }
            })
            .catch(error => {
                console.error('Permission check failed:', error);
            });
    });
});

// Helper function to protect specific actions
function requirePermission(permission, action) {
    permissionSystem.checkPermission(permission, action);
}
</script>

<!-- CSS for permission-protected elements -->
<style>
[data-permission]:not(.permission-allowed) {
    position: relative;
}

[data-permission].permission-denied {
    opacity: 0.6;
    cursor: not-allowed;
}

[data-permission].permission-denied::after {
    content: "\f023"; /* Lock icon */
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

.modal-content {
    border-radius: 12px;
}

.permission-badge {
    display: inline-flex;
    align-items: center;
    gap: 4px;
    padding: 2px 8px;
    background-color: #fff3cd;
    border: 1px solid #ffeaa7;
    border-radius: 4px;
    font-size: 0.75em;
    color: #856404;
}

/* Permission tooltip */
.permission-tooltip {
    position: relative;
    cursor: help;
}

.permission-tooltip:hover::after {
    content: attr(data-permission-name);
    position: absolute;
    bottom: 100%;
    left: 50%;
    transform: translateX(-50%);
    background: #333;
    color: white;
    padding: 4px 8px;
    border-radius: 4px;
    font-size: 12px;
    white-space: nowrap;
    z-index: 1000;
}
</style>