<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Basic login required for viewing (all users can view confirmation)
AuthHelper::requireLogin();

$receiving_id = $_GET['receiving_id'] ?? null;
if (!$receiving_id) {
    header("Location: " . BASE_URL . "receiving");
    exit;
}

// Fetch uploaded photos
$stmt = $pdo->prepare("SELECT file_path FROM whsale_inventory_pro_receiving_photos WHERE receiving_id = ?");
$stmt->execute([$receiving_id]);
$photos = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-5 mb-5">
    <div class="alert alert-success shadow-sm">
        <h5 class="mb-2">
            <i class="fas fa-check-circle me-2"></i>
            Receiving Log #<?= htmlspecialchars($receiving_id) ?> Created Successfully
        </h5>
        <p class="mb-0">You can now add inventory items received on this pallet.</p>
    </div>

    <?php if (!empty($photos)): ?>
        <div class="mt-4">
            <h6><i class="fas fa-images me-2"></i>Uploaded Photos:</h6>
            <div class="d-flex flex-wrap gap-2">
                <?php foreach ($photos as $photo): ?>
                    <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>"
                         class="img-thumbnail" style="width: 100px; height: 100px; object-fit: cover;">
                <?php endforeach; ?>
            </div>
        </div>
    <?php endif; ?>

    <div class="mt-4 d-flex flex-wrap gap-2">
        <!-- UPDATED: Add permission check for inventory addition -->
        <?php if (RoleHelper::hasPermission('add_inventory')): ?>
            <a href="<?= BASE_URL ?>inventory/add?receiving_id=<?= urlencode($receiving_id) ?>" 
               class="btn btn-dark" data-permission="add_inventory">
                <i class="fas fa-plus me-1"></i>Add Inventory Items
            </a>
        <?php else: ?>
            <button class="btn btn-dark opacity-50" disabled 
                    title="You need permission to add inventory items" 
                    data-permission="add_inventory">
                <i class="fas fa-plus me-1"></i>Add Inventory Items
            </button>
        <?php endif; ?>
        
        <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>" class="btn btn-outline-primary">
            <i class="fas fa-eye me-1"></i>View Log Details
        </a>
        
        <a href="<?= BASE_URL ?>receiving" class="btn btn-outline-secondary">
            <i class="fas fa-arrow-left me-1"></i>Back to Receiving List
        </a>
    </div>

    <!-- UPDATED: Add helpful information based on permissions -->
    <div class="mt-4">
        <div class="card border-0 bg-light">
            <div class="card-body">
                <h6 class="card-title">
                    <i class="fas fa-info-circle me-2"></i>What's Next?
                </h6>
                <ul class="mb-0">
                    <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                        <li>Add inventory items to track what was received</li>
                    <?php else: ?>
                        <li class="text-muted">Contact your administrator to get permission to add inventory items</li>
                    <?php endif; ?>
                    
                    <?php if (RoleHelper::hasPermission('upload_receiving_photos')): ?>
                        <li>Upload additional photos if needed</li>
                    <?php else: ?>
                        <li class="text-muted">Contact your administrator to get permission to upload photos</li>
                    <?php endif; ?>
                    
                    <?php if (RoleHelper::hasPermission('edit_receiving_logs')): ?>
                        <li>Edit the receiving log details if corrections are needed</li>
                    <?php else: ?>
                        <li class="text-muted">Contact your administrator to get permission to edit receiving logs</li>
                    <?php endif; ?>
                </ul>
            </div>
        </div>
    </div>
</div>

<!-- UPDATED: Custom CSS for permission-disabled elements -->
<style>
.btn.opacity-50 {
    opacity: 0.5 !important;
    cursor: not-allowed;
}

.btn.opacity-50:hover {
    opacity: 0.5 !important;
}

.text-muted li {
    color: #6c757d !important;
}

/* Responsive adjustments */
@media (max-width: 768px) {
    .d-flex.flex-wrap.gap-2 {
        flex-direction: column;
    }
    
    .btn {
        text-align: center;
    }
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>