<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for deleting photos (higher permission level)
AuthHelper::requirePermissionAjax('delete_receiving_logs');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $photo_id = $_POST['photo_id'] ?? null;
    $user_id = AuthHelper::getUserId();
    $organization_id = $_SESSION['organization_id'];

    if ($photo_id && is_numeric($photo_id)) {
        try {
            // UPDATED: Enhanced security - check photo belongs to user's organization and get file path
            $stmt = $pdo->prepare("
                SELECT rp.id, rp.uploaded_by, rp.file_path, rl.organization_id 
                FROM whsale_inventory_pro_receiving_photos rp
                JOIN whsale_inventory_pro_receiving_log rl ON rp.receiving_id = rl.id
                WHERE rp.id = ?
            ");
            $stmt->execute([$photo_id]);
            $photo = $stmt->fetch();
            
            if (!$photo) {
                echo json_encode(['success' => false, 'message' => 'Photo not found']);
                exit;
            }
            
            // Check if user has permission to delete this photo
            if ($photo['organization_id'] != $organization_id) {
                echo json_encode(['success' => false, 'message' => 'Access denied']);
                exit;
            }
            
            // Only users with delete_receiving_logs permission can delete photos
            if (!RoleHelper::hasPermission('delete_receiving_logs')) {
                echo json_encode(['success' => false, 'message' => 'Permission denied']);
                exit;
            }
            
            // Delete from database
            $stmt = $pdo->prepare("DELETE FROM whsale_inventory_pro_receiving_photos WHERE id = ?");
            $stmt->execute([$photo_id]);
            
            // Delete physical file
            $file_path = __DIR__ . '/../../public/uploads/receiving/' . $photo['file_path'];
            if (file_exists($file_path)) {
                unlink($file_path);
            }
            
            echo json_encode([
                'success' => true, 
                'message' => 'Photo deleted successfully'
            ]);
            exit;
            
        } catch (Exception $e) {
            error_log("Error deleting photo: " . $e->getMessage());
            echo json_encode(['success' => false, 'message' => 'Database error']);
            exit;
        }
    }
}

echo json_encode(['success' => false, 'message' => 'Invalid request']);
exit;