<?php
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/db.php';

$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $first_name = trim($_POST['first_name'] ?? '');
    $last_name = trim($_POST['last_name'] ?? '');
    $email = trim($_POST['email'] ?? '');
    $password = $_POST['password'] ?? '';
    $confirm_password = $_POST['confirm_password'] ?? '';
    $organization_slug = trim($_POST['organization_slug'] ?? '');
    
    // Basic validation
    if ($first_name && $last_name && $email && $password && $confirm_password && $organization_slug) {
        if (!preg_match('/^[a-zA-Z0-9_-]{3,30}$/', $organization_slug)) {
            $error = "Organization slug must be 3–30 characters, using only letters, numbers, dashes, or underscores.";
        } elseif ($password !== $confirm_password) {
            $error = "Passwords do not match.";
        } else {
            // Check for existing email
            $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_users WHERE email = ?");
            $stmt->execute([$email]);
            if ($stmt->fetch()) {
                $error = "An account with this email already exists.";
            } else {
                // Check for existing slug
                $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_users WHERE organization_slug = ?");
                $stmt->execute([$organization_slug]);
                if ($stmt->fetch()) {
                    $error = "That organization name is already in use. Please choose another.";
                } else {
                    try {
                        // Start transaction
                        $pdo->beginTransaction();
                        
                        // Insert user first
                        $hash = password_hash($password, PASSWORD_DEFAULT);
                        $stmt = $pdo->prepare("
    INSERT INTO whsale_inventory_pro_users 
    (first_name, last_name, email, password_hash, organization_id, organization_slug, role, is_active, account_status, created_at)
    VALUES (?, ?, ?, ?, 0, ?, 'owner', 1, 'active', NOW())
");
$stmt->execute([$first_name, $last_name, $email, $hash, $organization_slug]);
                        
                        $newUserId = $pdo->lastInsertId();
                        
                        // Update user's organization_id to self (org owner pattern)
                        $stmt = $pdo->prepare("UPDATE whsale_inventory_pro_users SET organization_id = ? WHERE id = ?");
                        $stmt->execute([$newUserId, $newUserId]);
                        
                        // Insert into organizations table
                        $stmt = $pdo->prepare("
                            INSERT INTO whsale_inventory_pro_organizations
                            (organization_id, organization_slug, created_at)
                            VALUES (?, ?, NOW())
                        ");
                        $stmt->execute([$newUserId, $organization_slug]);
                        
                        // Create default branding for the organization
                        $stmt = $pdo->prepare("
                            INSERT INTO whsale_inventory_pro_org_branding
                            (organization_id, organization_display_name, primary_color, secondary_color, 
                             navbar_bg_color, navbar_text_color, body_bg_color, price_color,
                             heading_color, body_text_color, muted_text_color, card_bg_color, 
                             card_border_color, link_color, created_at)
                            VALUES (?, ?, '#f66903', '#ff9e49', '#ffffff', '#000000', '#f8f9fa', '#198754',
                                    '#212529', '#212529', '#6c757d', '#ffffff', '#dee2e6', '#0d6efd', NOW())
                        ");
                        $stmt->execute([$newUserId, ucfirst($organization_slug) . ' Store']);
                        
                        // Commit transaction
                        $pdo->commit();
                        
                        $success = "User registered successfully. You can now log in.";
                        
                    } catch (Exception $e) {
                        // Rollback transaction on error
                        $pdo->rollback();
                        $error = "Registration failed. Please try again.";
                        error_log("Registration error: " . $e->getMessage());
                    }
                }
            }
        }
    } else {
        $error = "Please fill in all required fields.";
    }
}
?>


<?php include __DIR__ . '/partials/auth_head.php'; ?>

<style>
    .btn-custom-green {
        background-color: #00f801;
        border-color: #00f801;
        color: #000;
    }

    .btn-custom-green:hover {
        background-color: #00df01;
        border-color: #00df01;
        color: #000;
    }

    .logo-header img {
        max-height: 120px;
    }

    .card-header {
        background-color: #ffffff !important;
        border-bottom: 1px solid #dee2e6;
    }
</style>

<div class="container min-vh-100 py-5 d-flex align-items-center justify-content-center">

    <div class="col-12 col-sm-10 col-md-8 col-lg-6 col-xl-5">
        <div class="card border-0 shadow-lg rounded-4">
            <div class="card-header text-center py-4">
                <div class="logo-header mb-3">
                    <img src="<?= BASE_URL ?>assets/logo.png" alt="<?= APP_NAME ?> Logo" class="img-fluid">
                </div>
                <h4 class="mb-0 fw-bold text-dark">Create Your Account</h4>
            </div>

            <div class="card-body p-5">
                <?php if ($error): ?>
                    <div class="alert alert-danger d-flex align-items-center" role="alert">
                        <i class="fas fa-exclamation-circle me-2"></i>
                        <?= htmlspecialchars($error) ?>
                    </div>
                <?php endif; ?>

                <?php if ($success): ?>
    <div class="alert alert-success d-flex align-items-center flex-column text-center" role="alert">
        <div>
            <i class="fas fa-check-circle me-2"></i>
            <?= htmlspecialchars($success) ?>
        </div>
        <div class="mt-2">
            <a href="<?= BASE_URL ?>login" class="btn btn-sm btn-outline-dark">
                <i class="fas fa-sign-in-alt me-1"></i>Go to Login
            </a>
        </div>
<?php endif; ?>


                <form method="POST" class="mt-3" novalidate>
    <div class="form-floating mb-2">
        <input type="text" class="form-control" id="first_name" name="first_name" placeholder="First Name" required value="<?= htmlspecialchars($first_name ?? '') ?>">
        <label for="first_name"><i class="fas fa-user me-2"></i>First Name <span class="text-danger">*</span></label>
    </div>
    

    <div class="form-floating mb-2">
        <input type="text" class="form-control" id="last_name" name="last_name" placeholder="Last Name" required value="<?= htmlspecialchars($last_name ?? '') ?>">
        <label for="last_name"><i class="fas fa-user me-2"></i>Last Name <span class="text-danger">*</span></label>
    </div>
    

    <div class="form-floating mb-2">
        <input type="text" class="form-control" id="organization_slug" name="organization_slug" placeholder="your-store-name" required value="<?= htmlspecialchars($organization_slug ?? '') ?>">
        <label for="organization_slug"><i class="fas fa-store me-2"></i>Organization URL Name <span class="text-danger">*</span></label>
    </div>
    <div class="form-text mb-3 text-danger">3–30 characters; no spaces. Ex: BobsDiscountGrocery or bobs_discount_grocery (this will be used as your storefront URL extension name).</div>

    <div class="form-floating mb-2">
        <input type="email" class="form-control" id="email" name="email" placeholder="name@example.com" required value="<?= htmlspecialchars($email ?? '') ?>">
        <label for="email"><i class="fas fa-envelope me-2"></i>Email Address <span class="text-danger">*</span></label>
    </div>
    

    <div class="form-floating mb-2">
        <input type="password" class="form-control" id="password" name="password" placeholder="Password" required>
        <label for="password"><i class="fas fa-lock me-2"></i>Password <span class="text-danger">*</span></label>
    </div>
    

    <div class="form-floating mb-2">
        <input type="password" class="form-control" id="confirm_password" name="confirm_password" placeholder="Confirm Password" required>
        <label for="confirm_password"><i class="fas fa-lock me-2"></i>Confirm Password <span class="text-danger">*</span></label>
    </div>
    <div class="form-text mb-4 text-danger">Must match password</div>

    <div class="d-grid mb-3">
        <button type="submit" class="btn btn-custom-green btn-lg">
            <i class="fas fa-user-plus me-2"></i>Register
        </button>
    </div>

    <div class="text-center">
        <small class="text-muted">
            Already have an account?
            <a href="<?= BASE_URL ?>login" class="text-decoration-none fw-semibold">Log in here.</a>
        </small>
    </div>
</form>


            </div>
        </div>
    </div>
</div>

<?php include __DIR__ . '/partials/footer.php'; ?>
