<?php
require_once __DIR__ . '/../helpers/AuthHelper.php';
AuthHelper::requireLogin();

$id = $_GET['id'] ?? null;
$error = '';
$product = null;

if (!$id || !is_numeric($id)) {
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
}

try {
    $stmt = $pdo->prepare("CALL whsale_inventory_pro_get_storefront_product_by_id(?)");
    $stmt->execute([$id]);
    $product = $stmt->fetch();
    $stmt->closeCursor();

    if (!$product || $product['organization_id'] != $_SESSION['organization_id']) {
        throw new Exception("Unauthorized or invalid product.");
    }

    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $title = trim($_POST['title'] ?? '');
        $description = trim($_POST['description'] ?? '');
        $listed_price = $_POST['listed_price'] !== '' ? (float)$_POST['listed_price'] : null;
        $is_active = isset($_POST['is_active']) ? 1 : 0;

        if (!$title) {
            $error = 'Title is required.';
        } else {
            $updateStmt = $pdo->prepare("CALL whsale_inventory_pro_update_storefront_product(?, ?, ?, ?, ?)");
            $updateStmt->execute([$id, $title, $description, $listed_price, $is_active]);
            $updateStmt->closeCursor();

            header("Location: " . BASE_URL . "storefront/manage");
            exit;
        }
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<?php include __DIR__ . '/../../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <h4 class="mb-4">Edit Storefront Product</h4>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
    <?php endif; ?>

    <?php if ($product): ?>
        <form method="POST">
            <div class="mb-3">
                <label for="title" class="form-label">Title <span class="text-danger">*</span></label>
                <input type="text" name="title" id="title" class="form-control" value="<?= htmlspecialchars($product['title']) ?>" required>
            </div>

            <div class="mb-3">
                <label for="description" class="form-label">Description</label>
                <textarea name="description" id="description" class="form-control" rows="4"><?= htmlspecialchars($product['description']) ?></textarea>
            </div>

            <div class="mb-3">
                <label for="listed_price" class="form-label">Listed Price</label>
                <input type="number" name="listed_price" id="listed_price" class="form-control" step="0.01" value="<?= htmlspecialchars($product['listed_price']) ?>">
            </div>

            <div class="form-check mb-3">
                <input class="form-check-input" type="checkbox" name="is_active" id="is_active" <?= $product['is_active'] ? 'checked' : '' ?>>
                <label class="form-check-label" for="is_active">
                    Product is Active
                </label>
            </div>

            <button type="submit" class="btn btn-primary">Save Changes</button>
            <a href="<?= BASE_URL ?>storefront/manage" class="btn btn-secondary ms-2">Cancel</a>
        </form>
    <?php endif; ?>
</div>

<?php include __DIR__ . '/../../partials/footer.php'; ?>
